@@ -16,35 +16,64 @@
 #' both compositional parts. The ilr-transformation is then internally applied
 #' to each group independently whenever the \code{mult_comp} is set correctly.
 #' 
-#' @aliases pcaCoDa print.pcaCoDa
+#' @aliases pcaCoDa print.pcaCoDa 
 #' @param x compositional data
-#' @param method either \dQuote{robust} (default) or \dQuote{standard}
+#' @param method must be either \dQuote{robust} (default) or \dQuote{classical}
 #' @param mult_comp a list of numeric vectors holding the indices of linked
 #' compositions
+#' @param external external non-compositional variables
 #' @return \item{scores }{scores in clr space} \item{loadings }{loadings in clr
 #' space} \item{eigenvalues }{eigenvalues of the clr covariance matrix}
 #' \item{method }{method} \item{princompOutputClr }{output of \code{princomp}
 #' needed in \code{plot.pcaCoDa}}
 #' @author K. Hron, P. Filzmoser, M. Templ
+#' @seealso \code{\link{print.pcaCoDa}}, \code{\link{summary.pcaCoDa}}, \code{\link{biplot.pcaCoDa}}, \code{\link{plot.pcaCoDa}}
 #' @importFrom stats princomp
-#' @seealso \code{\link{print.pcaCoDa}}, \code{\link{plot.pcaCoDa}}
 #' @references Filzmoser, P., Hron, K., Reimann, C. (2009) Principal Component
 #' Analysis for Compositional Data with Outliers. \emph{Environmetrics},
 #' \bold{20}, 621-632.
+#' 
+#' Kynclova, P., Filzmoser, P., Hron, K. (2016) Compositional biplots including external non-compositional variables. 
+#' \emph{Statistics: A Journal of Theoretical and Applied Statistics},
+#' \bold{50}, 1132-1148.
 #' @keywords multivariate
 #' @export
 #' @importFrom MASS cov.mve
 #' @examples
 #' 
-#' data(expenditures)
-#' p1 <- pcaCoDa(expenditures)
-#' p1
-#' plot(p1)
+#' data(arcticLake)
 #' 
-#' ## just for illustration how to set the mult_comp argument
+#' ## robust estimation (default):
+#' res.rob <- pcaCoDa(arcticLake)
+#' res.rob
+#' summary(res.rob)
+#' plot(res.rob)
+#' 
+#' ## classical estimation:
+#' res.cla <- pcaCoDa(arcticLake, method="classical")
+#' biplot(res.cla)
+#' 
+#' ## just for illustration how to set the mult_comp argument:
+#' data(expenditures)
 #' p1 <- pcaCoDa(expenditures, mult_comp=list(c(1,2,3),c(4,5)))
 #' p1
-pcaCoDa <- function(x, method="robust",mult_comp=NULL){
+#' 
+#' ## example with external variables:
+#' data(election)
+#' # transform external variables
+#' election$unemployment <- log((election$unemployment/100)/(1-election$unemployment/100))
+#' election$income <- scale(election$income)
+#' 
+#' res <- pcaCoDa(election[,1:6], method="classical", external=election[,7:8])
+#' res
+#' biplot(res, scale=0)
+
+pcaCoDa <- function(x, method="robust", mult_comp=NULL, external=NULL){
+ 
+  if(is.vector(external) & length(external)!=nrow(x)){ 
+      stop("external and x must have the same number of observations")
+  }
+  if(!is.null(mult_comp) & !is.list(mult_comp)) stop("if specified, mult_comp must be a list")
   
   # Closure problem with ilr transformation
   ilrV <- function(x){
@@ -59,7 +88,10 @@ pcaCoDa <- function(x, method="robust",mult_comp=NULL){
     xilr <- ilrV(x)
   }else{
     xilr <- do.call("cbind",lapply(mult_comp,function(xx)ilrV(x[,xx])))
-  }		
+  }
+  if(!is.null(external)){
+    xilr <- cbind(xilr, external)
+  }
   if( method == "robust"){
     cv <- robustbase::covMcd(xilr, cor=FALSE)
     pcaIlr <- suppressWarnings(princomp(xilr, covmat=cv, cor=FALSE))
@@ -74,6 +106,7 @@ pcaCoDa <- function(x, method="robust",mult_comp=NULL){
   }
   # construct orthonormal basis
   if(is.null(mult_comp)){
+    #V <- matrix(0, nrow=ncol(x), ncol=ncol(x)-length(external)-1)
     V <- matrix(0, nrow=ncol(x), ncol=ncol(x)-1)
     for( i in 1:ncol(V) ){
       V[1:i,i] <- 1/i
@@ -100,18 +133,25 @@ pcaCoDa <- function(x, method="robust",mult_comp=NULL){
   }
   
  
-  
-  
   # robust ilr result - back-transformed to clr-space
-  
-  loadings <- V %*% pcaIlr$loadings	
+  if(!is.null(external)){
+    nload <- nrow(pcaIlr$loadings)
+    if(dim(external)[2] < 2) index <- 1
+    else index <- ncol(external)
+    loadings <- V %*% pcaIlr$loadings[-c((nload-index+1):nload),] # transform without external loadings
+    loadings <- rbind(loadings, pcaIlr$loadings[(nload-index+1):nload,]) 
+  }
+  else{
+    loadings <- V %*% pcaIlr$loadings
+  }
   if(is.null(mult_comp)){
-    if(!is.null(names(x))) dimnames(loadings)[[1]] <- names(x)
+    if(!is.null(names(x)) & !is.null(external)) dimnames(loadings)[[1]] <- c(names(x), names(external))
+    else if(!is.null(names(x))) dimnames(loadings)[[1]] <- names(x)
   }else{
     if(!is.null(names(x))) dimnames(loadings)[[1]] <- colnames(x)[unlist(mult_comp)]
   }
   pcaClr <- pcaIlr
-#	pcaClr$scores <- pcaIlr$scores %*% t(V)
+#  pcaClr$scores <- pcaIlr$scores %*% t(V)
   pcaClr$scores <- pcaIlr$scores 
   pcaClr$loadings <- loadings
   
@@ -135,7 +175,17 @@ print.pcaCoDa <- function(x, ...){
   eV <- x$eigenvalues / sum(x$eigenvalues)
   eVcum <- cumsum(x$eigenvalues) / sum(x$eigenvalues)
   cat("\n-------------------")
-  cat("\n Percentages of explained variability for compositional data after clr transformation \n")
+  cat("\n Percentages of explained variability for compositional data \n after clr transformation \n")
   print(eVcum)
   cat("\n-------------------\n\n")	
 }
+
+#' @rdname pcaCoDa
+#' @method summary pcaCoDa
+#' @param object object of class pcaCoDa
+#' @export
+
+summary.pcaCoDa <- function(object, ...){
+    stopifnot(inherits(object, "pcaCoDa"))
+    summary(object$princompOutputClr)
+}
